#include <stdio.h>
#include <stdlib.h>
#include <audiere.h>
using namespace audiere;


#ifdef _WIN32

#include <windows.h>

inline void sleepSecond ()
{
	Sleep ( 1000 );
}

#else  // assume POSIX

#include <unistd.h>

inline void sleepSecond ()
{
	sleep ( 1 );
}

#endif


int main ( int argc, const char * argv [] )
{
	if ( argc != 2 && argc != 3 )
	{
    	printf ( "usage: simple <filename> [<device>]\n" );

	    return 1;
	}

	printf ( "initializing...\n" );

	const char * deviceName = "";

	if ( argc == 3 )
		deviceName = argv [2];

	AudioDevicePtr device = OpenDevice ( deviceName );

											// check for errors
	if ( !device )
	{
    	printf ( "OpenDevice() failed\n" );

		return 1;
	}

	printf ( "opened device %s\n", device -> getName () );

	OutputStreamPtr sound = OpenSound ( device, argv [1] );

	if ( !sound )
	{
    	printf ( "OpenSound() failed\n" );

		return 1;
	}

	printf ( "opened sound, length %d\n", sound -> getLength () );

	sound -> play ();

	printf ( "started playback\n" );

	while ( sound -> isPlaying () )
	{
    		sleepSecond ();

		if ( sound -> isSeekable () )
      			printf ( "position: %d\n", sound -> getPosition () );
	}

	return 0;
}
